`puzzle_generator`
==================

Basic functionality of
[`puzzle_generator`](https://github.com/vil02/puzzle_generator)
it to generate a piece of python code representing a puzzle/quiz.
The answers and the upcoming questions are stored in an encrypted form,
so it is _difficult_ to read them before providing correct answers.
The output is a single file without any dependencies.

Examples and documentation can be found on [GitHub](https://github.com/vil02/puzzle_generator).